
// vim: set filetype=pp2html:
//
// ATTENTION: File automatically created by extract_pod.pl
//            DO NOT EDIT, changes will be lost

* \XREF{name="--activeContents"}<--activeContents>

* \XREF{name="--alinkcolor=color"}<--alinkcolor=color>

* \XREF{name="--back_image"}<--back_image>

* \XREF{name="--bgcolor=color"}<--bgcolor=color>

* \XREF{name="--block_indent=m"}<--block_indent=m>

* \XREF{name="--bot_back_image"}<--bot_back_image>

* \XREF{name="--bot_bgcolor=color"}<--bot_bgcolor=color>

* \XREF{name="--bot_fgcolor=color"}<--bot_fgcolor=color>

* \XREF{name="--bot_left_txt"}<--bot_left_txt>

* \XREF{name="--bot_middle_txt"}<--bot_middle_txt>

* \XREF{name="--bot_right_txt"}<--bot_right_txt>

* \XREF{name="--bottom_idx_template=filename"}<--bottom_idx_template=filename>

* \XREF{name="--bottom_template=filename"}<--bottom_template=filename>

* \XREF{name="--bottom_toc_template=filename"}<--bottom_toc_template=filename>

* \XREF{name="--box_border=width"}<--box_border=width>

* \XREF{name="--box_color=color"}<--box_color=color>

* \XREF{name="--box_width=width"}<--box_width=width>

* \XREF{name="--boxtext_bold=OFF"}<--boxtext_bold=OFF>

* \XREF{name="--boxtext_bold=ON"}<--boxtext_bold=ON>

* \XREF{name="--boxtext_color=color"}<--boxtext_color=color>

* \XREF{name="--bullet=filename"}<--bullet=filename>

* \XREF{name="--cache"}<--cache>

* \XREF{name="--cacheCleanup"}<--cacheCleanup>

* \XREF{name="--center_headers"}<--center_headers>

* \XREF{name="--contents_header=text"}<--contents_header=text>

* \XREF{name="--contents_table_width=m"}<--contents_table_width=m>

* \XREF{name="--contents_target"}<--contents_target>

* \XREF{name="--count_only"}<--count_only>

* \XREF{name="--fgcolor=color"}<--fgcolor=color>

* \XREF{name="--filter=regexp"}<--filter=regexp>

* \XREF{name="--frame_set=filename"}<--frame_set=filename>

* \XREF{name="--frame_start=filename"}<--frame_start=filename>

* \XREF{name="--idx_back_image"}<--idx_back_image>

* \XREF{name="--idx_bgcolor=color"}<--idx_bgcolor=color>

* \XREF{name="--idx_fgcolor=color"}<--idx_fgcolor=color>

* \XREF{name="--image_dir=dirname"}<--image_dir=dirname>

* \XREF{name="--index_bot=n"}<--index_bot=n>

* \XREF{name="--index_dat=n"}<--index_dat=n>

* \XREF{name="--index_header=text"}<--index_header=text>

* \XREF{name="--index_top=n"}<--index_top=n>

* \XREF{name="--java_script_navigation=value"}<--java_script_navigation=value>

* \XREF{name="--linear_mode"}<--linear_mode>

* \XREF{name="--linkcolor=color"}<--linkcolor=color>

* \XREF{name="--logo_image_filename"}<--logo_image_filename>

* \XREF{name="--nav_bottom_template=filename"}<--nav_bottom_template=filename>

* \XREF{name="--nav_template=filename"}<--nav_template=filename>

* \XREF{name="--nav_top_template=filename"}<--nav_top_template=filename>

* \XREF{name="--no_contents_bullets"}<--no_contents_bullets>

* \XREF{name="--no_contents_indent"}<--no_contents_indent>

* \XREF{name="--no_index"}<--no_index>

* \XREF{name="--nocopyright"}<--nocopyright>

* \XREF{name="--noinfo"}<--noinfo>

* \XREF{name="--nonum_headers"}<--nonum_headers>

* \XREF{name="--nowarn"}<--nowarn>

* \XREF{name="--num_headers"}<--num_headers>

* \XREF{name="--quiet"}<--quiet>

* \XREF{name="--safeOpcode=opcode"}<--safeOpcode=opcode>

* \XREF{name="--set=flag"}<--set=flag>

* \XREF{name="--slide_dir=directory"}<--slide_dir=directory>

* \XREF{name="--slide_md5"}<--slide_md5>

* \XREF{name="--slide_prefix=text"}<--slide_prefix=text>

* \XREF{name="--slide_suffix=text"}<--slide_suffix=text>

* \XREF{name="--start_page=filename"}<--start_page=filename>

* \XREF{name="--style=style_name"}<--style=style_name>

* \XREF{name="--style_dir=style_dirname"}<--style_dir=style_dirname>

* \XREF{name="--style_sheet=style_sheet_name"}<--style_sheet=style_sheet_name>

* \XREF{name="--target_dir=directory"}<--target_dir=directory>

* \XREF{name="--title=text"}<--title=text>

* \XREF{name="--toc_back_image"}<--toc_back_image>

* \XREF{name="--toc_bgcolor=color"}<--toc_bgcolor=color>

* \XREF{name="--toc_fgcolor=color"}<--toc_fgcolor=color>

* \XREF{name="--top_back_image"}<--top_back_image>

* \XREF{name="--top_bgcolor=color"}<--top_bgcolor=color>

* \XREF{name="--top_fgcolor=color"}<--top_fgcolor=color>

* \XREF{name="--top_idx_template=filename"}<--top_idx_template=filename>

* \XREF{name="--top_left_txt"}<--top_left_txt>

* \XREF{name="--top_middle_txt"}<--top_middle_txt>

* \XREF{name="--top_right_txt"}<--top_right_txt>

* \XREF{name="--top_template=filename"}<--top_template=filename>

* \XREF{name="--top_toc_template=filename"}<--top_toc_template=filename>

* \XREF{name="--trans_table=filename"}<--trans_table=filename>

* \XREF{name="--tree_app_height=m"}<--tree_app_height=m>

* \XREF{name="--tree_app_width=m"}<--tree_app_width=m>

* \XREF{name="--tree_applet"}<--tree_applet>

* \XREF{name="--tree_base"}<--tree_base>

* \XREF{name="--vlinkcolor=color"}<--vlinkcolor=color>



==activeContents


\A{name="--activeContents"}\B<\X<--activeContents>>

PerlPoint sources can embed Perl code which is evaluated while the 
source is parsed. For reasons of security this feature is deactivated 
by default. Set this option to activate it. You can use 
MKITALI\C<--safeOpcode> to fine tune which operations shall be 
permitted. 



==cache


\A{name="--cache"}\B<\X<--cache>>

parsing of one and the same document several times can be accelerated 
by activating the PerlPoint parser cache by this option. The 
performance boost depends on your document structure. 

Cache files are written besides the source and named ".<source 
file>.ppcache". 

It can be useful to (temporarily) deactivate the cache to get correct 
line numbers in parser error messages (currently numbers cannot always 
reported correctly with activated cache because of a special perl 
behaviour). 



==cacheCleanup


\A{name="--cacheCleanup"}\B<\X<--cacheCleanup>>

PerlPoint parser cache files grow (with every modified version of a 
source parsed) because they store expressions for every parsed variant 
of a paragraph. This is usually uncritical but you may wish to clean 
up the cache occasionally. Use this option to perform the task (or 
remove the cache file manually). 





==safeOpcode=opcode


\A{name="--safeOpcode=opcode"}\B<\X<--safeOpcode=opcode>>

If active contents is enabled (MKITALI\C<--activeContents>), Perl code 
embedded into the translated PerlPoint sources will be evaluated. To 
keep security this is done via an object of class \B<Safe> which 
restricts code to permitted operations. By this option you can declare 
which opcode (or opcode tag) is permitted. Please see the \B<Safe> and 
\B<Opcode> manual pages for further details. (These modules come with 
perl.) 

Pass \C<ALL> to allow MKITALI\C<everything>. 

This option can be used multiply. 

You may want to store these options in default option files, see below 
for details. 



For the examples used in MKITALI\C<ppdoc.pp> you should use 

 --safeOpcode=:filesys_open --safeOpcode=:still_to_be_decided --safeOpcode=:browse






==set=flag


\A{name="--set=flag"}\B<\X<--set=flag>>

This option allows you to pass certain settings - of your choice - to 
active contents (like conditions) where it can be accessed via the 
$PerlPoint hash reference. For example, your PerlPoint code could 
contain a condition like 

  ? $PerlPoint->{userSettings}{special}


  Special part.


  ? 1


The special part enclosed by the two conditions would then be 
processed MKITALI\C<only> if you call \C<pp2html> with 

  --set special


and if active contents was enabled by MKITALI\C<-active>, of course. 

This option can be used multiply. 



==trans_table=filename


\A{name="--trans_table=filename"}\B<\X<--trans_table=filename>>

The \C<--trans_table> option specifies a the filename of a tanslation 
table for non ASCII characters like german Umlaute etc. The characters 
are specifed as octal numbers as in the folowing example: 

  #Translation Table for German Umlaute (this is the default)


  \334 &Uuml;
  \374 &uuml;


  \326 &Ouml;
  \366 &ouml;


  \304 &Auml;
  \344 &auml;


  \337 &szlig;






==filter=regexp


\A{name="--filter=regexp"}\B<\X<--filter=regexp>>

This specifies a regular expression \C<regexp> which should match all 
allowed languages for EMBEDed code. The expression is evaluated 
caseinsensitively. 

Example: --filter="perl|html" 



==nocopyright


\A{name="--nocopyright"}\B<\X<--nocopyright>>

suppresses the copyright message; 



==noinfo


\A{name="--noinfo"}\B<\X<--noinfo>>

supresses runtime informations; 



==nowarn


\A{name="--nowarn"}\B<\X<--nowarn>>

supresses warnings; 



==quiet


\A{name="--quiet"}\B<\X<--quiet>>

a shortcut for "--nocopyright --noinfo --nowarn": all non critical 
runtime messages are suppressed; 



==count_only


\A{name="--count_only"}\B<\X<--count_only>>

If this option is set, only a counter will indicate that slides are 
created. Otherwise for all slides the full header is printed while 
generating the slides. 





==box_color=color


\A{name="--box_color=color"}\B<\X<--box_color=color>>


\A{name="--boxtext_color=color"}\B<\X<--boxtext_color=color>>

Set background and forground colors for block paragraphs 





==bgcolor=color


\A{name="--bgcolor=color"}\B<\X<--bgcolor=color>>


\A{name="--fgcolor=color"}\B<\X<--fgcolor=color>>


\A{name="--idx_bgcolor=color"}\B<\X<--idx_bgcolor=color>>


\A{name="--idx_fgcolor=color"}\B<\X<--idx_fgcolor=color>>


\A{name="--toc_bgcolor=color"}\B<\X<--toc_bgcolor=color>>


\A{name="--toc_fgcolor=color"}\B<\X<--toc_fgcolor=color>>


\A{name="--top_bgcolor=color"}\B<\X<--top_bgcolor=color>>


\A{name="--top_fgcolor=color"}\B<\X<--top_fgcolor=color>>


\A{name="--bot_bgcolor=color"}\B<\X<--bot_bgcolor=color>>


\A{name="--bot_fgcolor=color"}\B<\X<--bot_fgcolor=color>>


\A{name="--linkcolor=color"}\B<\X<--linkcolor=color>>


\A{name="--alinkcolor=color"}\B<\X<--alinkcolor=color>>


\A{name="--vlinkcolor=color"}\B<\X<--vlinkcolor=color>>

Set the background and foreground color for all HTML pages. The 
\C<idx_> and \C<toc_> options are for the index page and table of 
contents respectively. The last three options set the colors for 
hyperlinks, active links and followed links. The linkcolor options can 
also be prefixed with \C<top>, \C<bot>, \C<toc> and \C<idx> for 
example \C<--toc_linkcolor white>. 



==back_image


\A{name="--back_image"}\B<\X<--back_image>>


\A{name="--toc_back_image"}\B<\X<--toc_back_image>>


\A{name="--idx_back_image"}\B<\X<--idx_back_image>>


\A{name="--top_back_image"}\B<\X<--top_back_image>>


\A{name="--bot_back_image"}\B<\X<--bot_back_image>>

Set background image for nomal slides, table of contents, index, top 
frame or bottom frame. 





==top_template=filename


\A{name="--top_template=filename"}\B<\X<--top_template=filename>>


\A{name="--top_idx_template=filename"}\B<\X<--top_idx_template=filename>>


\A{name="--top_toc_template=filename"}\B<\X<--top_toc_template=filename>>


\A{name="--bottom_template=filename"}\B<\X<--bottom_template=filename>>


\A{name="--bottom_idx_template=filename"}\B<\X<--bottom_idx_template=filename>>


\A{name="--bottom_toc_template=filename"}\B<\X<--bottom_toc_template=filename>>


\A{name="--nav_template=filename"}\B<\X<--nav_template=filename>>


\A{name="--nav_top_template=filename"}\B<\X<--nav_top_template=filename>>


\A{name="--nav_bottom_template=filename"}\B<\X<--nav_bottom_template=filename>>

Filenames for template files (in HTML format). The bottom template is 
appended to each slide. Can be used to create footers with navigation, 
copyright note etc. The top template is inserted at the top of each 
slide. 

The \C<_idx_> templates are used for the index slide and the \C<_toc_> 
templates are used for the table of contents slide. 

The \C<nav_top> and \C<nav_bottom> templates are included in all pages 
on top, just below the \C<top_template> and at the bottom just before 
the \C<bottom_template>. If the \C<--nav_template> option is set, the 
\C<nav_template> will be used on top and at the bottom unless you 
specify \C<--nav_top_template> or \C<--nav_bottom_template>. The 
latter both will overwrite the \C<--nav_template> option. 

\B<NOTE:> Templates should not contain <HTML>, <HEAD>, <TITLE> or 
<BODY> tags. These tags are always written by \C<pp2html>. There is, 
however, one exception: If you use the \C<--frame_set> option without 
java script navigation (see below), then the top and bottom HTML 
templates should be directly included in the frame set template and 
should be full HTML files with HEAD and BODY lines. 

The following keywords are substituted with corresponding values when 
the templates are included: 

  TITLE               text specified by --title option
  URL_NEXT            hyperlink to next page
  TXT_NEXT            header of next page
  URL_PREV            hyperlink to previous page
  TXT_PREV            header of previous page
  URL_FIRST           hyperlink to first page
  TXT_FIRST           header of first page
  URL_LAST            hyperlink to last page
  TXT_LAST            header of last page
  URL_UP              hyperlink to upper page
  TXT_UP              header of upper page
  URL_DOWN            hyperlink to subsection page
  TXT_DOWN            header of subsection page
  URL_CONTENTS        hyperlink to contents page
  TXT_CONTENTS        text specified by --contents_header
  URL_INDEX           hyperlink to index page
  TXT_INDEX           text specified by --index_header
  LABEL_NEXT          label text for "next" link
  LABEL_PREV          label text for "previous" link
  LABEL_CONTENTS      label text for "contents" link
  LABEL_INDEX         label text for "index" link
  PAGE_CNT            number of pages
  PAGE                page or chapter number
  TOP_LEFT_TXT        text for left side in top templates, see --top_left_txt
  TOP_RIGHT_TXT       text for right side in top templates, see --top_right_txt
  TOP_MIDDLE_TXT      text for middle in top templates, see --top_middle_txt
  BOT_LEFT_TXT        text for left side in bottom templates, see --bot_left_txt
  BOT_RIGHT_TXT       text for right side in bottom templates, see --bot_right_txt
  BOT_MIDDLE_TXT      text for middle in bottom templates, see --bot_middle_txt
  LOGO_IMAGE_FILENAME text for the logo image filename in template files, 
                      see --logo_image_filename




==top_left_txt


\A{name="--top_left_txt"}\B<\X<--top_left_txt>>


\A{name="--top_right_txt"}\B<\X<--top_right_txt>>


\A{name="--top_middle_txt"}\B<\X<--top_middle_txt>>


\A{name="--bot_left_txt"}\B<\X<--bot_left_txt>>


\A{name="--bot_right_txt"}\B<\X<--bot_right_txt>>


\A{name="--bot_middle_txt"}\B<\X<--bot_middle_txt>>


\A{name="--logo_image_filename"}\B<\X<--logo_image_filename>>

These texts will be used to replace the corresponding keywords in 
template files which are used in the slides. See for example the 
orange_slides style. 



==boxtext_bold=ON


\A{name="--boxtext_bold=ON"}\B<\X<--boxtext_bold=ON>>


\A{name="--boxtext_bold=OFF"}\B<\X<--boxtext_bold=OFF>>

Text in colored textboxes will be printed \B<bold> or normal. 



==box_border=width


\A{name="--box_border=width"}\B<\X<--box_border=width>>

Set the border width of block paragraphs. 



==box_width=width


\A{name="--box_width=width"}\B<\X<--box_width=width>>

Set the width of block paragraphs. This assures that all colored boxes 
have the same width. 

Example: --box_width="80%" 



==bullet=filename


\A{name="--bullet=filename"}\B<\X<--bullet=filename>>

Filename of a GIF or JPEG image which is used for the bullets in 
bullet lists. This option can be used more than once. In this case the 
first occurance is used for top level lists, the second occurance for 
second level lists etc. 

\B<NOTE:> The filename must be given as an absolute pathname or 
relative to the directory where the \C<pp2html> program is started (i. 
e. relative to the directory where the PerlPoint input file resides). 
When the --style option is used, the filename must be specified 
relative to the directory where the style is defined. Normally all 
bullet images for a style reside in the style directory. 





==block_indent=m


\A{name="--block_indent=m"}\B<\X<--block_indent=m>>

Indent each block by m levels (i. e. put m <UL> </UL> containers 
around the block This can be used to shift the block boxes to the 
right. Looks better if a block paragraph occurs within a bullet list. 





==center_headers


\A{name="--center_headers"}\B<\X<--center_headers>>

Page Headers are centered. Default is no centering. 



==contents_header=text


\A{name="--contents_header=text"}\B<\X<--contents_header=text>>

Heading for contents page. Default is MKITALI\C<Contents> 



==frame_set=filename


\A{name="--frame_set=filename"}\B<\X<--frame_set=filename>>

filename for frame set template. This activates the frame set 
generation. 



==frame_start=filename


\A{name="--frame_start=filename"}\B<\X<--frame_start=filename>>

filename of the startfile for the frame set. The frame_set template is 
copied to this file in the slide_dir directory. 





==contents_target


\A{name="--contents_target"}\B<\X<--contents_target>>

This is used as the target frame in all hyperlinks to the table of 
contents. Useful for example if you have a frame set without an Index 
frame. In this case it might be usefull to set the 
\C<--contents_target> option to "Data". 



==contents_table_width=m


\A{name="--contents_table_width=m"}\B<\X<--contents_table_width=m>>

Specifies the width of the table used for the table of contents 
(unless the tree applet is uses). A value of 0 suppresses the width 
option in the HTML table. 



==index_bot=n


\A{name="--index_bot=n"}\B<\X<--index_bot=n>>


\A{name="--index_dat=n"}\B<\X<--index_dat=n>>


\A{name="--index_top=n"}\B<\X<--index_top=n>>

Indices of the bottom, top and index frames within the frame set. Used 
for java script navigation procedure. 





==index_header=text


\A{name="--index_header=text"}\B<\X<--index_header=text>>

Heading for index page. Default is MKITALI\C<Index> 



==no_index


\A{name="--no_index"}\B<\X<--no_index>>

Do not create an index 



==java_script_navigation=value


\A{name="--java_script_navigation=value"}\B<\X<--java_script_navigation=value>>

value=1: on, value=0: off. If java_script_navigation is on and frame 
sets are generated then for each page a separate top and bottom page 
is created which is used in the top and bottom frames of the frame 
set. If java_script_navigation is off, then only one top template and 
one bottom template will be used for all pages. (In this case there 
should be no place holders for PAGE etc. in theses templates ... and 
they should be complete HTML Files.) 

\B<NOTE:> This option is mainly used in combination with the 
\C<--tree_applet> option because \B<it is not possible> to use the 
tree applet with javascript navigation (the tree applet cannot call 
URLs which contain javascript function calls). 



==linear_mode


\A{name="--linear_mode"}\B<\X<--linear_mode>>

This option influences the behaviour of PREV and NEXT links. In linear 
mode all pages form a linear sequence which can be traversed by means 
of the PREV and NEXT links. When this option is not set then the PREV 
and NEXT links work only on the same level. For example is it possible 
to traverse the sequence 2.1.1, 2.1.2, 2.1.3, 2.1.4 with PREV and NEXT 
links but the first section has no PREV link and the last one has no 
NEXT link. In such a constellation the UP and DOWN links may be used 
to change the level and go the the next higher section or step down to 
a subsection. 



==num_headers


\A{name="--num_headers"}\B<\X<--num_headers>>


\A{name="--nonum_headers"}\B<\X<--nonum_headers>>

All page headers are preceeded/not preceeded by the chapter number 
(e.g. 2.2.3) which is determined by the position of the page and the 
level of its header. The \C<--nonum_headers> overwrites a previous 
\C<num_headers> option which allows to overwrite options from 
predefined styles. 



==no_contents_indent


\A{name="--no_contents_indent"}\B<\X<--no_contents_indent>>


\A{name="--no_contents_bullets"}\B<\X<--no_contents_bullets>>

These two options influence the appearance of the table of contents. 
The first one prevents the indentation and the second one avoids 
bullets in front of each entry. 





==slide_dir=directory


\A{name="--slide_dir=directory"}\B<\X<--slide_dir=directory>>


\A{name="--target_dir=directory"}\B<\X<--target_dir=directory>>

Directory in which the HTML files are to be created. 



==slide_prefix=text


\A{name="--slide_prefix=text"}\B<\X<--slide_prefix=text>>

Prefix for all HTML files. Default is "Slide". 



==slide_suffix=text


\A{name="--slide_suffix=text"}\B<\X<--slide_suffix=text>>

Suffix for all HTML files. Default is "htm". 



==slide_md5


\A{name="--slide_md5"}\B<\X<--slide_md5>>

This option specifies, that all filenames should have the form 
<slide_prefix><md5_checksum>.<slide_suffix> e. g. 
\C<slide85b9a93686f5416d2f85964a33fad95b.htm>. The \C<md5_checksum> is 
calculated from the slide header. This can be usful, if there are many 
changes in your document (addition/removal of slides) and you use 
hyperlinks to pages of your document from within other documents. 

\B<NOTE:> This feature is still experimental. 



==title=text


\A{name="--title=text"}\B<\X<--title=text>>

Text which is substituted for the TITLE keyword in template files. 



==tree_applet


\A{name="--tree_applet"}\B<\X<--tree_applet>>

Activate usage of TreeApplet 



==tree_app_width=m


\A{name="--tree_app_width=m"}\B<\X<--tree_app_width=m>>


\A{name="--tree_app_height=m"}\B<\X<--tree_app_height=m>>

Width and height of the tree applet area. 



==tree_base


\A{name="--tree_base"}\B<\X<--tree_base>>

Codebase option for the tree applet. Default is ./ 





==style=style_name


\A{name="--style=style_name"}\B<\X<--style=style_name>>


\A{name="--style_dir=style_dirname"}\B<\X<--style_dir=style_dirname>>

Using pre-defined styles. Styles are pre-defined collections of 
templates and configuration files which are stored in a directory 
whose name is the name of this style. Several of such styles can be 
placed in a style directory (collection of styles). 

With \C<--style_dir=style_dirname> you can specify one or more style 
directories (the option can be used more than once). All specified 
style directories are searched for the style which is given by the 
\C<--style> option. 

Examples of styles are delivered with the PerlPoint-Converters 
distribution. 



==style_sheet=style_sheet_name


\A{name="--style_sheet=style_sheet_name"}\B<\X<--style_sheet=style_sheet_name>>

MKITALI\C<This option is still experimental>. It allows to specifiy a 
style sheet (.css) which will be referenced in HTML <head> tags in all 
slides. It is not well tested and the settings in the style sheet may 
conflict with some layout tricks used by pp2html. 



==image_dir=dirname


\A{name="--image_dir=dirname"}\B<\X<--image_dir=dirname>>

This is the name of the image directory in the target area. All images 
from the style directory and from the PerlPoint source are copied to 
this location. 



==start_page=filename


\A{name="--start_page=filename"}\B<\X<--start_page=filename>>

The default for this option is "index.htm". The table of contents 
slide or the frame set start page is copied to this filename unless 
the \\C<--start_page> option is set to the empty string. This is 
useful for web pages because most browsers automatically open the 
"index.htm" if it exists. For example, if you have installed your 
document or presentation at "http://somewhere.net/Example", a web 
browser will automatically open the first page of your document if the 
browser is directed to this URL. 

